@@ -15,7 +15,8 @@ format_option = partial(
     click.option, '--format', '-f', 'format_',
     help='Format for the file names. For example, "{name}-{space}-{date:%x}.txt" '
          'may produce "File 3-3-11/02/20.txt" depending on your locale. '
-         'See more date formatting options at https://docs.python.org/3/library/datetime.html#strftime-and-strptime-format-codes')
+         'See more date formatting options at'
+         ' https://docs.python.org/3/library/datetime.html#strftime-and-strptime-format-codes')
 
 
 @click.group()
@@ -57,9 +58,10 @@ def applets():
 
 
 @applets.command('list')
-def applets_list():
-    applets = commands.list_applets()
-    print(json.dumps(applets, indent=2))
+def list_applets():
+    """ Get a list of installed applets. """
+    applet_list = commands.list_applets()
+    print(json.dumps(applet_list, indent=2))
 
 
 @applets.command('get-settings')
@@ -67,7 +69,7 @@ def applets_list():
 @click.argument('flag', type=int, nargs=-1)
 def applet_get_settings(applet_id, flag):
     """
-    List settings. Note that it is possible for the call to return
+    List settings of an applet. Note that it is possible for the call to return
     different subsets of settings on multiple runs.
 
     The meaning of the flag depends on the applet and is not documented.
@@ -77,18 +79,20 @@ def applet_get_settings(applet_id, flag):
     print(json.dumps(settings, indent=2, default=json_default))
 
 
-@applets.command('set-settings')
+@applets.command('set-settings',
+                 short_help='Update settings. Use this at your own risk - invalid settings' +
+                            ' may disrupt work of an applet or the device.')
 @click.argument('applet_id', type=int)
 @click.argument('ident', type=int)
 @click.argument('value', nargs=-1)
 def applet_set_settings(applet_id, ident, value):
     """
-    To learn what settings are available for an applet, run get-settings.
-
-    !!! Use this at your own risk - invalid settings may disrupt work of
+    Use this at your own risk - invalid settings may disrupt work of
     an applet or the device. There is validation for options and applet ids,
     but not for the open-ended values such as ranges and strings.
 
+    To learn what settings are available for an applet, run get-settings.
+
     The value depends on type of the setting: number for option id and applet id,
     string for passwords, and three numbers for the ranges.
 
@@ -103,12 +107,50 @@ def applet_set_settings(applet_id, ident, value):
     commands.applet_write_settings(applet_id, ident, value)
 
 
+@applets.command('fetch')
+@click.argument('applet_id', type=int)
+@click.argument('path', type=click.Path())
+def fetch_applet(applet_id, path):
+    """
+    Fetch the applet file from the device and write to file.
+
+    Get a list of applets to find out the ids. The id 0 would fetch the firmware ROM.
+    """
+    commands.fetch_applet(applet_id, path)
+
+
+@applets.command('remove-all')
+def remove_applets():
+    """ Delete all applets from the device. """
+    click.confirm(text='Are you sure you want to remove all applets?', abort=True)
+    commands.remove_applets()
+
+
+@applets.command('remove',
+                 short_help="Experimental. Delete an applet from the device. Note that it does not free the space.")
+@click.argument('applet_id', type=int)
+def remove_applet(applet_id):
+    """ Delete an applet from the device. """
+    click.confirm(text='Are you sure you want to remove applet?' +
+                       'It will not free up the space and is meant only for development.', abort=True)
+    commands.remove_applet(applet_id)
+
+
+@applets.command('install', short_help="Experimental. Install an applet. Use this at your own risk.")
+@click.argument('path', type=click.Path(exists=True, dir_okay=False))
+@click.option('--force', '-f', default=False, is_flag=True, help='Skip check if the applet exists')
+def install_applet(path, force):
+    click.confirm(text='Are you sure you want to install an applet? ' +
+                       'This is an experimental feature.', abort=True)
+    commands.install_applet(path, force)
+
+
 @files.command("list")
 @applet_id_option()
 @click.option('--verbose', '-v', default=False, is_flag=True, help='All file attributes')
 def list_all_files(applet_id, verbose):
-    files = commands.list_files(applet_id, verbose)
-    print(json.dumps(files, indent=2, default=json_default))
+    files_list = commands.list_files(applet_id, verbose)
+    print(json.dumps(files_list, indent=2, default=json_default))
 
 
 @files.command('read')
@@ -136,10 +178,17 @@ def write_file(path, file_name_or_space):
     commands.write_file(file_name_or_space, contents)
 
 
+@cli.command('info')
+def system_info():
+    """ General system information """
+    info = commands.system_info()
+    print(json.dumps(info, indent=2))
+
+
 @files.command('clear')
 @applet_id_option()
 @file_name_or_space_arg()
-def clear(applet_id, file_name_or_space):
+def clear_file(applet_id, file_name_or_space):
     commands.clear_file(applet_id, file_name_or_space)
 
 
